import React, { useEffect, useState } from 'react';
import { PlusCircle } from 'lucide-react';
import { AddServerModal } from './components/AddServerModal';
import { ServerCard } from './components/ServerCard';
import { Server, ServerMetrics } from './types';
import { supabase } from './lib/supabase';

function App() {
  const [servers, setServers] = useState<Server[]>([]);
  const [showAddModal, setShowAddModal] = useState(false);
  const [metrics, setMetrics] = useState<Record<string, ServerMetrics[]>>({});

  useEffect(() => {
    fetchServers();
  }, []);

  const fetchServers = async () => {
    const { data } = await supabase
      .from('servers')
      .select('*')
      .order('created_at', { ascending: true });
    
    if (data) {
      setServers(data);
      data.forEach(server => {
        fetchMetrics(server);
      });
    }
  };

  const fetchMetrics = async (server: Server) => {
    // In a real implementation, this would fetch from InfluxDB
    // For demo purposes, we'll generate mock data
    const mockMetrics: ServerMetrics[] = Array.from({ length: 20 }).map((_, i) => ({
      cpu_usage: Math.random() * 100,
      ram_usage: Math.random() * 100,
      timestamp: new Date(Date.now() - (19 - i) * 60000).toISOString()
    }));
    
    setMetrics(prev => ({
      ...prev,
      [server.id]: mockMetrics
    }));
  };

  return (
    <div className="min-h-screen bg-gray-900 text-white p-8">
      <div className="max-w-7xl mx-auto">
        <div className="flex justify-between items-center mb-8">
          <h1 className="text-3xl font-bold">Proxmox Dashboard</h1>
          <button
            onClick={() => setShowAddModal(true)}
            className="flex items-center space-x-2 bg-blue-600 px-4 py-2 rounded-lg hover:bg-blue-700 transition-colors"
          >
            <PlusCircle size={20} />
            <span>Add Server</span>
          </button>
        </div>

        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
          {servers.map(server => (
            <ServerCard
              key={server.id}
              server={server}
              metrics={metrics[server.id] || []}
            />
          ))}
        </div>

        {showAddModal && (
          <AddServerModal
            onClose={() => setShowAddModal(false)}
            onServerAdded={fetchServers}
          />
        )}
      </div>
    </div>
  );
}

export default App;